==> huaweicloudsdkwaf-3.0.49-py2.py3-none-any.whl: huaweicloudsdkwaf/v1/model/show_instance_route_request.py <==
# coding: utf-8

import pprint
import re

import six





class ShowInstanceRouteRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instanceid': 'str'
    }

    attribute_map = {
        'instanceid': 'instanceid'
    }

    def __init__(self, instanceid=None):
        """ShowInstanceRouteRequest - a model defined in huaweicloud sdk"""
        
        

        self._instanceid = None
        self.discriminator = None

        self.instanceid = instanceid

    @property
    def instanceid(self):
        """Gets the instanceid of this ShowInstanceRouteRequest.

        域名Id

        :return: The instanceid of this ShowInstanceRouteRequest.
        :rtype: str
        """
        return self._instanceid

    @instanceid.setter
    def instanceid(self, instanceid):
        """Sets the instanceid of this ShowInstanceRouteRequest.

        域名Id

        :param instanceid: The instanceid of this ShowInstanceRouteRequest.
        :type: str
        """
        self._instanceid = instanceid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowInstanceRouteRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkwaf-3.0.52-py2.py3-none-any.whl: huaweicloudsdkwaf/v1/model/show_instance_route_request.py <==
# coding: utf-8

import re
import six





class ShowInstanceRouteRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instanceid': 'str'
    }

    attribute_map = {
        'instanceid': 'instanceid'
    }

    def __init__(self, instanceid=None):
        """ShowInstanceRouteRequest - a model defined in huaweicloud sdk"""
        
        

        self._instanceid = None
        self.discriminator = None

        self.instanceid = instanceid

    @property
    def instanceid(self):
        """Gets the instanceid of this ShowInstanceRouteRequest.

        域名Id

        :return: The instanceid of this ShowInstanceRouteRequest.
        :rtype: str
        """
        return self._instanceid

    @instanceid.setter
    def instanceid(self, instanceid):
        """Sets the instanceid of this ShowInstanceRouteRequest.

        域名Id

        :param instanceid: The instanceid of this ShowInstanceRouteRequest.
        :type: str
        """
        self._instanceid = instanceid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowInstanceRouteRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
